@@ -1,3 +1,7 @@
+//! CLI argparser configuration, command detection and input treatment.
+//!
+//! NOTE: the argparser implementation itself is not in this file.
+
 use std::{
     env,
     ffi::OsString,
@@ -94,7 +98,7 @@ pub fn parse_args_from(mut args: Vec<OsString>) -> crate::Result<ParsedArgs> {
         return Ok(ParsedArgs { command: Command::ShowVersion, flags: oof::Flags::default() });
     }
 
-    let subcommands = &["c", "compress"];
+    let subcommands = &["c", "compress", "d", "decompress"];
     let mut flags_info = vec![flag!('y', "yes"), flag!('n', "no")];
 
     let parsed_args = match oof::pop_subcommand(&mut args, subcommands) {
@@ -113,8 +117,7 @@ pub fn parse_args_from(mut args: Vec<OsString>) -> crate::Result<ParsedArgs> {
             let command = Command::Compress { files, output_path };
             ParsedArgs { command, flags }
         }
-        // Defaults to decompression when there is no subcommand
-        None => {
+        Some(&"d") | Some(&"decompress") => {
             flags_info.push(arg_flag!('o', "output"));
 
             if let Some(first_arg) = args.first() {
@@ -136,6 +139,10 @@ pub fn parse_args_from(mut args: Vec<OsString>) -> crate::Result<ParsedArgs> {
             let command = Command::Decompress { files, output_folder };
             ParsedArgs { command, flags }
         }
+        // Defaults to help when there is no subcommand
+        None => {
+            return Ok(ParsedArgs { command: Command::ShowHelp, flags: oof::Flags::default() });
+        }
         _ => unreachable!("You should match each subcommand passed."),
     };
 
@@ -147,9 +154,9 @@ mod tests {
 
     use super::*;
 
-    fn gen_args(text: &str) -> Vec<OsString> {
+    fn gen_args<T: From<OsString>>(text: &str) -> Vec<T> {
         let args = text.split_whitespace();
-        args.map(OsString::from).collect()
+        args.map(OsString::from).map(T::from).collect()
     }
 
     fn test_cli(args: &str) -> crate::Result<ParsedArgs> {
@@ -159,18 +166,28 @@ mod tests {
 
     #[test]
     fn test_cli_commands() {
+        assert_eq!(test_cli("").unwrap().command, Command::ShowHelp);
         assert_eq!(test_cli("--help").unwrap().command, Command::ShowHelp);
         assert_eq!(test_cli("--version").unwrap().command, Command::ShowVersion);
         assert_eq!(test_cli("--version").unwrap().flags, oof::Flags::default());
         assert_eq!(
-            test_cli("foo.zip bar.zip").unwrap().command,
-            Command::Decompress { files: vec!["foo.zip".into(), "bar.zip".into()], output_folder: None }
+            test_cli("decompress foo.zip bar.zip").unwrap().command,
+            Command::Decompress { files: gen_args("foo.zip bar.zip"), output_folder: None }
+        );
+        assert_eq!(
+            test_cli("d foo.zip bar.zip").unwrap().command,
+            Command::Decompress { files: gen_args("foo.zip bar.zip"), output_folder: None }
         );
         assert_eq!(
             test_cli("compress foo bar baz.zip").unwrap().command,
-            Command::Compress { files: vec!["foo".into(), "bar".into()], output_path: "baz.zip".into() }
+            Command::Compress { files: gen_args("foo bar"), output_path: "baz.zip".into() }
+        );
+        assert_eq!(
+            test_cli("c foo bar baz.zip").unwrap().command,
+            Command::Compress { files: gen_args("foo bar"), output_path: "baz.zip".into() }
         );
         assert_eq!(test_cli("compress").unwrap_err(), Error::MissingArgumentsForCompression);
+        // assert_eq!(test_cli("decompress").unwrap_err(), Error::MissingArgumentsForCompression); // TODO
     }
 
     #[test]
@@ -180,7 +197,7 @@ mod tests {
         assert_eq!(test_cli("--version").unwrap().flags, oof::Flags::default());
 
         assert_eq!(
-            test_cli("foo --yes bar --output folder").unwrap().flags,
+            test_cli("decompress foo --yes bar --output folder").unwrap().flags,
             oof::Flags {
                 boolean_flags: vec!["yes"].into_iter().collect(),
                 argument_flags: vec![("output", OsString::from("folder"))].into_iter().collect(),
