@@ -1,3 +1,7 @@
+//! Core of the crate, where the `compress_files` and `decompress_file` functions are implemented
+//!
+//! Also, where correctly call functions based on the detected `Command`.
+
 use std::{
     fs,
     io::{self, BufReader, BufWriter, Read, Write},
@@ -18,6 +22,9 @@ use crate::{
     utils::to_utf,
 };
 
+// Used in BufReader and BufWriter to perform less syscalls
+const BUFFER_CAPACITY: usize = 1024 * 64;
+
 pub fn run(command: Command, flags: &oof::Flags) -> crate::Result<()> {
     match command {
         Command::Compress { files, output_path } => {
@@ -146,7 +153,7 @@ fn compress_files(
     output_file: fs::File,
     _flags: &oof::Flags,
 ) -> crate::Result<()> {
-    let file_writer = BufWriter::new(output_file);
+    let file_writer = BufWriter::with_capacity(BUFFER_CAPACITY, output_file);
 
     if formats.len() == 1 {
         let build_archive_from_paths = match formats[0] {
@@ -166,6 +173,13 @@ fn compress_files(
                 Gzip => Box::new(flate2::write::GzEncoder::new(encoder, Default::default())),
                 Bzip => Box::new(bzip2::write::BzEncoder::new(encoder, Default::default())),
                 Lzma => Box::new(xz2::write::XzEncoder::new(encoder, 6)),
+                Zstd => {
+                    let zstd_encoder = zstd::stream::write::Encoder::new(encoder, Default::default());
+                    // Safety:
+                    //     Encoder::new() can only fail if `level` is invalid, but Default::default()
+                    //     is guaranteed to be valid
+                    Box::new(zstd_encoder.unwrap().auto_finish())
+                }
                 _ => unreachable!(),
             };
             encoder
@@ -176,7 +190,7 @@ fn compress_files(
         }
 
         match formats[0] {
-            Gzip | Bzip | Lzma => {
+            Gzip | Bzip | Lzma | Zstd => {
                 writer = chain_writer_encoder(&formats[0], writer);
                 let mut reader = fs::File::open(&files[0]).unwrap();
                 io::copy(&mut reader, &mut writer)?;
@@ -243,27 +257,28 @@ fn decompress_file(
     }
 
     // Will be used in decoder chaining
-    let reader = BufReader::new(reader);
+    let reader = BufReader::with_capacity(BUFFER_CAPACITY, reader);
     let mut reader: Box<dyn Read> = Box::new(reader);
 
     // Grab previous decoder and wrap it inside of a new one
-    let chain_reader_decoder = |format: &CompressionFormat, decoder: Box<dyn Read>| {
+    let chain_reader_decoder = |format: &CompressionFormat, decoder: Box<dyn Read>| -> crate::Result<Box<dyn Read>> {
         let decoder: Box<dyn Read> = match format {
             Gzip => Box::new(flate2::read::GzDecoder::new(decoder)),
             Bzip => Box::new(bzip2::read::BzDecoder::new(decoder)),
             Lzma => Box::new(xz2::read::XzDecoder::new(decoder)),
+            Zstd => Box::new(zstd::stream::Decoder::new(decoder)?),
             _ => unreachable!(),
         };
-        decoder
+        Ok(decoder)
     };
 
     for format in formats.iter().skip(1).rev() {
-        reader = chain_reader_decoder(format, reader);
+        reader = chain_reader_decoder(format, reader)?;
     }
 
     match formats[0] {
-        Gzip | Bzip | Lzma => {
-            reader = chain_reader_decoder(&formats[0], reader);
+        Gzip | Bzip | Lzma | Zstd => {
+            reader = chain_reader_decoder(&formats[0], reader)?;
 
             // TODO: improve error treatment
             let mut writer = fs::File::create(&output_path)?;
