@@ -1,4 +1,12 @@
-use std::io::{self, Write};
+//! Pretty (and colored) dialog for asking [Y/n] for the end user.
+//!
+//! Example:
+//!     "Do you want to overwrite 'archive.targz'? [Y/n]"
+
+use std::{
+    borrow::Cow,
+    io::{self, Write},
+};
 
 use crate::utils::colors;
 
@@ -15,9 +23,9 @@ impl<'a> Confirmation<'a> {
 
     pub fn ask(&self, substitute: Option<&'a str>) -> crate::Result<bool> {
         let message = match (self.placeholder, substitute) {
-            (None, _) => self.prompt.into(),
+            (None, _) => Cow::Borrowed(self.prompt),
             (Some(_), None) => return Err(crate::Error::InternalError),
-            (Some(placeholder), Some(subs)) => self.prompt.replace(placeholder, subs),
+            (Some(placeholder), Some(subs)) => Cow::Owned(self.prompt.replace(placeholder, subs)),
         };
 
         loop {
@@ -35,7 +43,7 @@ impl<'a> Confirmation<'a> {
             match trimmed_answer.to_ascii_lowercase().as_ref() {
                 "y" | "yes" => return Ok(true),
                 "n" | "no" => return Ok(false),
-                _ => {}
+                _ => continue, // Try again
             }
         }
     }
