@@ -1,3 +1,9 @@
+//! This library is meant to be published, just used internally by our binary crate at `main.rs`.
+//!
+//! A module shall be public only if:
+//! 1. It's required by `main.rs`, or
+//! 2. It's required by some integration tests at tests/ folder.
+
 // Public modules
 pub mod cli;
 pub mod commands;
@@ -15,52 +21,35 @@ pub use error::{Error, Result};
 
 use lazy_static::lazy_static;
 
-pub const EXIT_FAILURE: i32 = 127;
+pub const EXIT_FAILURE: i32 = libc::EXIT_FAILURE;
 
-const VERSION: &str = "0.1.6";
+const VERSION: &'static str = env!("CARGO_PKG_VERSION");
 
 lazy_static! {
     static ref NO_COLOR_IS_SET: bool = {
         use std::env;
 
-        env::var("NO_COLOR").is_ok()
+        env::var("NO_COLOR").is_ok() || atty::isnt(atty::Stream::Stdout) || atty::isnt(atty::Stream::Stderr)
     };
 }
 
 fn help_command() {
     use utils::colors::*;
-    /*
-    ouch - Obvious Unified Compressed files Helper
-
-    USAGE:
-        ouch <files...>                        Decompresses files.
-
-        ouch compress <files...> OUTPUT.EXT    Compresses files into OUTPUT.EXT,
-                                               where EXT must be a supported format.
-
-    FLAGS:
-        -h, --help    Display this help information.
-        -y, --yes     Skip overwrite questions.
-        -n, --no      Skip overwrite questions.
-        --version     Display version information.
-
-    SPECIFIC FLAGS:
-        -o, --output FOLDER_PATH    When decompressing, to decompress files to
-                                    another folder.
-
-    Visit https://github.com/vrmiguel/ouch for more usage examples.
-    */
 
     println!(
         "\
 {cyan}ouch{reset} - Obvious Unified Compression files Helper
 
 {cyan}USAGE:{reset}
-    {green}ouch {magenta}<files...>{reset}                        Decompresses files.
+    {green}ouch decompress {magenta}<files...>{reset}             Decompresses files.
 
     {green}ouch compress {magenta}<files...> OUTPUT.EXT{reset}    Compresses files into {magenta}OUTPUT.EXT{reset},
                                            where {magenta}EXT{reset} must be a supported format.
 
+{cyan}ALIASES:{reset}
+    {green}d    decompress {reset}
+    {green}c    compress {reset}
+
 {cyan}FLAGS:{reset}
     {yellow}-h{white}, {yellow}--help{reset}    Display this help information.
     {yellow}-y{white}, {yellow}--yes{reset}     Skip overwrite questions.
@@ -71,7 +60,7 @@ fn help_command() {
     {yellow}-o{reset}, {yellow}--output{reset} FOLDER_PATH    When decompressing, to decompress files to
                                 another folder.
 
-Visit https://github.com/vrmiguel/ouch for more usage examples.",
+Visit https://github.com/ouch-org/ouch for more usage examples.",
         magenta = magenta(),
         white = white(),
         green = green(),
