@@ -1,3 +1,5 @@
+mod utils;
+
 use std::{
     env, fs,
     io::prelude::*,
@@ -6,6 +8,7 @@ use std::{
 
 use ouch::{cli::Command, commands::run, oof};
 use rand::{rngs::SmallRng, RngCore, SeedableRng};
+use utils::*;
 
 #[test]
 /// Tests each format that supports multiple files with random input.
@@ -18,6 +21,7 @@ fn test_each_format() {
     test_compressing_and_decompressing_archive("tar.xz");
     test_compressing_and_decompressing_archive("tar.lz");
     test_compressing_and_decompressing_archive("tar.lzma");
+    test_compressing_and_decompressing_archive("tar.zst");
     test_compressing_and_decompressing_archive("zip");
     test_compressing_and_decompressing_archive("zip.gz");
     test_compressing_and_decompressing_archive("zip.bz");
@@ -28,7 +32,7 @@ fn test_each_format() {
 
     // Why not
     test_compressing_and_decompressing_archive(
-        "tar.gz.gz.gz.gz.gz.gz.gz.gz.gz.gz.gz.gz.gz.gz.gz.gz.gz.gz.lz.lz.lz.lz.lz.lz.lz.lz.lz.lz.bz.bz.bz.bz.bz.bz.bz",
+        "tar.gz.gz.gz.gz.gz.gz.gz.gz.zst.gz.gz.gz.gz.gz.gz.gz.gz.gz.gz.lz.lz.lz.lz.lz.lz.lz.lz.lz.lz.bz.bz.bz.bz.bz.bz.bz",
     );
 }
 
@@ -94,16 +98,6 @@ fn create_files(at: &Path, contents: &[FileContent]) -> Vec<PathBuf> {
         .collect()
 }
 
-fn compress_files(at: &Path, paths_to_compress: &[PathBuf], format: &str) -> PathBuf {
-    let archive_path = String::from("archive.") + format;
-    let archive_path = at.join(archive_path);
-
-    let command = Command::Compress { files: paths_to_compress.to_vec(), output_path: archive_path.to_path_buf() };
-    run(command, &oof::Flags::default()).expect("Failed to compress test dummy files");
-
-    archive_path
-}
-
 fn extract_files(archive_path: &Path) -> Vec<PathBuf> {
     // We will extract in the same folder as the archive
     // If the archive is at:
